/***************************************************************************
* Copyright (c) 2017, Sylvain Corlay and Johan Mabille                     *
*                                                                          *
* Distributed under the terms of the BSD 3-Clause License.                 *
*                                                                          *
* The full license is in the file LICENSE, distributed with this software. *
****************************************************************************/

#ifndef XPLOT_CONFIG_CLING_HPP
#define XPLOT_CONFIG_CLING_HPP

#pragma cling add_library_path("D:/bld/xplot_1579711110659/_h_env/Library/lib")
#pragma cling load("libxplot")

#endif
